@@ -47,3 +47,7 @@ class GenerationResponse(BaseModel):
     model_id: Optional[str] = Field(None, alias='modelId')
     meta: Optional[Usage]
 
+
+class ChunkedGenerationResponse(BaseModel):
+    event: str
+    data: dict
